GetxController class abstract
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
no setterinherited
- isClosed → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → VoidCallback -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void -
override
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
inherited
-
onReady(
) → void -
inherited
-
onStart(
) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited